<template>
  <div class="body"></div>
</template>

<script>
import {gantt} from 'dhtmlx-gantt'  // 组件插件
import 'dhtmlx-gantt/codebase/dhtmlxgantt.css' // 组件样式


export default {
  name: "index",
  data() {
    return {
      data: [
        {id: 11, text: "Project #1", type: "project", progress: 0.6, open: true},

        {id: 12, text: "Task #1", start_date: "03-04-2023", duration: "5", parent: "11", progress: 1, open: true},
        {id: 13, text: "Task #2", start_date: "03-04-2023", type: "project", parent: "11", progress: 0.5, open: true},
        {id: 14, text: "Task #3", start_date: "02-04-2023", duration: "6", parent: "11", progress: 0.8, open: true},
        {id: 15, text: "Task #4", type: "project", parent: "11", progress: 0.2, open: true},
        {
          id: 16,
          text: "Final milestone",
          start_date: "15-04-2023",
          type: "milestone",
          rollup: true,
          parent: "11",
          progress: 0,
          open: true
        },

        {id: 17, text: "Task #2.1", start_date: "03-04-2023", duration: "2", parent: "13", progress: 1, open: true},
        {id: 18, text: "Task #2.2", start_date: "06-04-2023", duration: "3", parent: "13", progress: 0.8, open: true},
        {id: 19, text: "Task #2.3", start_date: "10-04-2023", duration: "4", parent: "13", progress: 0.2, open: true},
        {id: 20, text: "Task #2.4", start_date: "10-04-2023", duration: "4", parent: "13", progress: 0, open: true},
        {id: 21, text: "Task #4.1", start_date: "03-04-2023", duration: "4", parent: "15", progress: 0.5, open: true},
        {id: 22, text: "Task #4.2", start_date: "03-04-2023", duration: "4", parent: "15", progress: 0.1, open: true},
        {
          id: 23,
          text: "Mediate milestone",
          start_date: "13-04-2023",
          type: "milestone",
          parent: "15",
          rollup: true,
          progress: 0,
          open: true
        }
      ],
      links: [
        {id: "10", source: "11", target: "12", type: "1"},
        {id: "11", source: "11", target: "13", type: "1"},
        {id: "12", source: "11", target: "14", type: "1"},
        {id: "13", source: "11", target: "15", type: "1"},
        {id: "14", source: "23", target: "16", type: "0"},
        {id: "15", source: "13", target: "17", type: "1"},
        {id: "16", source: "17", target: "18", type: "0"},
        {id: "17", source: "18", target: "19", type: "0"},
        {id: "18", source: "19", target: "20", type: "0"},
        {id: "19", source: "15", target: "21", type: "2"},
        {id: "20", source: "15", target: "22", type: "2"},
        {id: "21", source: "15", target: "23", type: "0"}
      ]
    }
  },
  mounted() {
    gantt.resetLightbox();
    this.init();
  },
  methods: {
    init() {
      const dom = document.querySelector(".body");

      gantt.message({
        text: [
          "请注意，里程碑显示在摘要行上",
          "双击任务即可查看可用选项。"
        ].join("<br><br>"),
        expire: -1
      });

      gantt.config.scale_height = 50;

      gantt.config.scales = [
        {unit: "month", step: 1, format: "%F, %Y"},
        {unit: "day", step: 1, format: "%j, %D"}
      ];

      gantt.templates.rightside_text = function (start, end, task) {
        if (task.type == "milestone") {
          return task.text;
        }
        return "";
      }

      gantt.config.lightbox.sections = [
        {name: "description", height: 70, map_to: "text", type: "textarea", focus: true},
        {name: "rollup", type: "checkbox", map_to: "rollup"},
        {name: "hide_bar", type: "checkbox", map_to: "hide_bar"},
        {name: "type", type: "typeselect", map_to: "type"},
        {name: "time", type: "duration", map_to: "auto"}
      ];

      gantt.config.lightbox.milestone_sections = [
        {name: "description", height: 70, map_to: "text", type: "textarea", focus: true},
        {name: "rollup", type: "checkbox", map_to: "rollup"},
        {name: "hide_bar", type: "checkbox", map_to: "hide_bar"},
        {name: "type", type: "typeselect", map_to: "type"},
        {name: "time", type: "duration", map_to: "auto"}
      ];

      gantt.config.lightbox.project_sections = [
        {name: "description", height: 70, map_to: "text", type: "textarea", focus: true},
        {name: "hide_bar", type: "checkbox", map_to: "hide_bar"},
        {name: "type", type: "typeselect", map_to: "type"},
        {name: "time", type: "duration", map_to: "auto"}
      ];

      // 鼠标操作甘特图--悬浮显示详情、拖动条目、拖动图等配置
      gantt.plugins({
        click_drag: true,//用于启用或禁用通过单击任务条目并拖动来更改任务的开始和结束日期的功能
        drag_timeline: true,// 拖动图
        marker: true,// 时间标记
        fullscreen: true,// 全屏
        tooltip: true,// 鼠标经过时信息
        undo: true, // 允许撤销
        quick_info: true
      })

      // 初始化
      gantt.init(dom);

      // 填充数据
      gantt.parse({
        data: this.data,
        links: this.links
      })

      // 重新渲染
      gantt.render()

      // 重新加载或刷新甘特图的数据的
      gantt.refreshData()

      // 设置本地化语言
      gantt.i18n.setLocale("cn");

      gantt.locale.labels.section_rollup = "任务汇总";
      gantt.locale.labels.section_hide_bar = "隐藏进度条";

      // 跟新甘特图标记
      // gantt.updateMarker(标记数据对象)

      // 清空数据
      // gantt.clearAll();

      //添加
      gantt.attachEvent("onAfterTaskAdd", function (id, item) {
        // console.log("添加后触发");
      });

      //移动进度
      gantt.attachEvent("onAfterTaskDrag", function (id, mode, e) {
        console.log("移动进度后触发");
      });

      //移动任务
      gantt.attachEvent("onAfterTaskMove", function (id, parent, tindex) {
        console.log("移动任务后触发");
      });

      //删除任务
      gantt.attachEvent("onAfterTaskDelete", function (id, item) {
        console.log("删除");
      });

      //修改任务
      gantt.attachEvent("onAfterTaskUpdate", function (id, item) {
        console.log("修改");
      })

      // 获取任务总数
      gantt.getTaskCount()

    },
  }
}
</script>

<style scoped lang="less">
.body {
  width: 100%;
  height: 100%;
}
</style>
